@@ -81,12 +81,10 @@
 #' 
 #' @aliases plsRglm plsRglmmodel.default plsRglmmodel.formula PLS_glm
 #' PLS_glm_formula
-#' @param x a formula or a response (training) dataset
-#' @param dataY response (training) dataset
-#' @param dataX predictor(s) (training) dataset
-#' @param formula an object of class "\code{\link{formula}}" (or one that can
+#' @param object a response (training) dataset or an object of class "\code{\link{formula}}" (or one that can
 #' be coerced to that class): a symbolic description of the model to be fitted.
 #' The details of model specification are given under 'Details'.
+#' @param dataX predictor(s) (training) dataset
 #' @param data an optional data frame, list or environment (or object coercible
 #' by \code{\link{as.data.frame}} to a data frame) containing the variables in
 #' the model. If not found in \code{data}, the variables are taken from
@@ -367,7 +365,7 @@
 #' }
 #' 
 #' @export plsRglm
-plsRglm <- function(x, ...) UseMethod("plsRglmmodel")
+plsRglm <- function(object, ...) UseMethod("plsRglmmodel")
 
 #' @rdname plsRglm
 #' @aliases plsRglm
